@@ -462,7 +462,7 @@ class CubicWebRequestBase(DBAPIRequest):
             try:
                 name, peid = param.split(':', 1)
             except ValueError:
-                if not param.startswith('__') and param != "eid":
+                if not param.startswith('__') and param not in ('eid', '_cw_fields'):
                     self.warning('param %s mis-formatted', param)
                 continue
             if peid == eid:
@@ -624,8 +624,10 @@ class CubicWebRequestBase(DBAPIRequest):
         extraparams.setdefault('fname', 'view')
         url = self.build_url('json', **extraparams)
         cbname = build_cb_uid(url[:50])
+        # think to propagate pageid. XXX see https://www.cubicweb.org/ticket/1753121
         jscode = 'function %s() { $("#%s").%s; }' % (
-            cbname, nodeid, js.loadxhtml(url, None, 'get', replacemode))
+            cbname, nodeid, js.loadxhtml(url, {'pageid': self.pageid},
+                                         'get', replacemode))
         self.html_headers.add_post_inline_script(jscode)
         return "javascript: %s()" % cbname
 
