@@ -28,11 +28,13 @@ class BreadCrumbsTC(CubicWebTC):
         self.execute('SET F2 filed_under F1 WHERE F1 eid %(f1)s, F2 eid %(f2)s',
                      {'f1' : f1.eid, 'f2' : f2.eid})
         self.commit()
-        self.assertEquals(f2.view('breadcrumbs'),
+        self.assertEqual(f2.view('breadcrumbs'),
                           '<a href="http://testing.fr/cubicweb/folder/%s" title="">chi&amp;ld</a>' % f2.eid)
         childrset = f2.as_rset()
-        ibc = self.vreg['components'].select('breadcrumbs', self.request(), rset=childrset)
-        self.assertEquals(ibc.render(),
+        ibc = self.vreg['ctxcomponents'].select('breadcrumbs', self.request(), rset=childrset)
+        l = []
+        ibc.render(l.append)
+        self.assertEqual(''.join(l),
                           """<span id="breadcrumbs" class="pathbar">&#160;&gt;&#160;<a href="http://testing.fr/cubicweb/Folder">folder_plural</a>&#160;&gt;&#160;<a href="http://testing.fr/cubicweb/folder/%s" title="">par&amp;ent</a>&#160;&gt;&#160;
 <a href="http://testing.fr/cubicweb/folder/%s" title="">chi&amp;ld</a></span>""" % (f1.eid, f2.eid))
 
